@@ -10,6 +10,7 @@ from dxi._lib import dx_logging
 from dxi._lib import get_references
 from dxi._lib import run_job
 from dxi._lib.run_async import run_async
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
@@ -22,8 +23,8 @@ class DXIContainerConstants(object):
     ALL_DBS = False
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     BCK_FILE = None
     USE_BACKUP = False
     USE_BACKUP = False
